// engine.js
const VSCodeFileManager = require('./filemanager');
const vscode = require('vscode');

class EngineHandler {
    constructor(statusBarItem) {
        this.totalAdditions = 0;
        this.totalDeletions = 0;
        this.statusBarItem = statusBarItem;
    }

    handleDocumentChange(event) {
        console.log(JSON.stringify(event))

        const filename = event.document.fileName

        if ((filename.length < 6 || filename.slice(-6) !== '.proof') && event.contentChanges.length > 0) {
            // Log the changes in the file

            // crate formatted string
            const formattedChange = {
                time: new Date().toISOString(),
                change: event.contentChanges
            }
            const changeString = JSON.stringify(formattedChange, {space: true})

            // log to file
            console.log(changeString)
            VSCodeFileManager.write('.proof', changeString).catch((error) => {
                console.error('Write operation failed, please contact developers:', error);
            }).then((didwork) => {
                if (!didwork) {
                    console.error('Write operation failed, please contact developers');
                    vscode.window.showErrorMessage('Write failed, your code is not being proofed, please contact the developers');
                }
            })
        }
    }

    updateStatusBar() {
        this.statusBarItem.text = `$(diff-added) +${this.totalAdditions} $(diff-removed) -${this.totalDeletions}`;
    }
}

module.exports = EngineHandler;
