// extension.js
const vscode = require('vscode');
const EngineHandler = require('./engine');
const Communicator = require('./communicator');


function activate(context) {
    console.log('Character tracker activated');
    const communicator = new Communicator();
    
    // Start with default settings
    communicator.setBaseInterval(1);  // 1 minute base interval
    communicator.setMaxInterval(30);  // 30 minute maximum
    communicator.start();
    
    // Create status bar item to show current stats
    const statusBarItem = vscode.window.createStatusBarItem(
        vscode.StatusBarAlignment.Right,
        100
    );
    statusBarItem.show();

    // Initialize engine handler
    const engine = new EngineHandler(statusBarItem);

    // Document change handler
    let changeDisposable = vscode.workspace.onDidChangeTextDocument(event => {
        engine.handleDocumentChange(event);
    });

    // Add to subscriptions
    context.subscriptions.push(changeDisposable, statusBarItem);
}

function deactivate() {}

module.exports = {
    activate,
    deactivate
};